import setuptools, sys

def get_requires():
    requires = []
    try:
        import PySide2
    except ModuleNotFoundError:
        try:
            import PySide6
        except ModuleNotFoundError:
            if sys.version_info < (3, 7):
                print("Will install PySide2.")
                requires = ['PySide2']
            else:
                print("Will install PySide6.")
                requires = ['PySide6']
    return requires

def readme():
    try:
        with open('README.md') as f:
            return f.read()
    except IOError:
        return ''



setuptools.setup(
name="PySimpleGUIQt",
version="5.0.0",
author="PySimpleSoft Inc.",
author_email="",
install_requires=get_requires(),
description="Python GUIs for Humans! PySimpleGUI is the top-rated Python application development environment. Launched in 2018 and actively developed, maintained, and supported in 2024. Transforms tkinter, Qt, WxPython, and Remi into a simple, intuitive, and fun experience for both hobbyists and expert users.",
long_description=readme(),
long_description_content_type="text/markdown",
license='Free To Use But Restricted',
keywords="GUI UI tkinter Qt WxPython Remi wrapper simple easy beginner novice student graphics pyside2 pyside6",
url="https://www.PySimpleGUI.com",
packages=setuptools.find_packages(),
python_requires=">=3.6",
classifiers=[
"Intended Audience :: Developers",
"License :: Other/Proprietary License",
"Operating System :: OS Independent",
"Framework :: PySimpleGUI",
"Framework :: PySimpleGUI :: 5",
"Programming Language :: Python :: 3",
"Programming Language :: Python :: 3.6",
"Programming Language :: Python :: 3.7",
"Programming Language :: Python :: 3.8",
"Programming Language :: Python :: 3.9",
"Programming Language :: Python :: 3.10",
"Programming Language :: Python :: 3.11",
"Programming Language :: Python :: 3.12",
"Programming Language :: Python :: 3.13",
"Topic :: Multimedia :: Graphics",
],
package_data={"": 
["CONTRIBUTING.md","LICENSE.txt","README.md"]
        },

)

